import os
import sys
import json
import pickle 
import numpy as np

from .apps import DgaClassifierConfig
from .dga_classifier_scripts.extract_features import extract_features_from_concat
from django.shortcuts import render
from django.http import JsonResponse
from django.views.decorators.csrf import csrf_exempt

# Create your views here.
def home(request):
    return render(request, "base.html", {})

@csrf_exempt  # For demo purposes, disable CSRF protection
def check_dga_domain(request):
    """Endpoint for domain DGA classification

    Args:
        request (HttpRequest): Request sent from client.

    Returns:
        dict: Dictionary containing the result of the binary
              and multiclass classifcation.
    """
    # 1. Initialize the model
    binary_model = DgaClassifierConfig.binary_model
    multiclass_model = DgaClassifierConfig.multiclass_model
    
    # 2. Initialize the objects for feature extraction
    tlds = DgaClassifierConfig.tlds
    ngrams = DgaClassifierConfig.ngrams
    
    if request.method == 'POST':
        print("Endpoint successful")
        try:
            # Get the data from the POST request
            data = json.loads(request.body.decode('utf-8'))
            domain = data['text']
            
            # 3. Extract features 
            features = np.array(
                extract_features_from_concat(
                    domain,
                    tlds.get_tlds(),
                    ngrams
                )
            ).reshape(1,-1)
            
            # 4. Binary classification
            dga = binary_model.predict_proba(features)
            dga = dga[0].tolist()
            dga = [round(i * 100, 3) for i in dga]
            treshold = 50
            dga_families = None
            if dga[1] >= treshold:
                # 5. Multiclass classification
                dga_families = multiclass_model.classify(features)
            
            response_data = {
                'binary_clf': dga, 
                'multiclass_clf' : dga_families
            }
            return JsonResponse(response_data)
        except KeyError:
            return JsonResponse({'error': 'Invalid data format'}, status=400)
    else:
        return JsonResponse({'error': 'Invalid request method'}, status=405)
