
/*
  File: dga_charts.js
  Author: Filip Bucko
  Date: 28.9.2023
  Description: Script creates and initializes the charts with default datasets.
*/
// =========== Global chart settings ===========

Chart.defaults.font.size = 16;
Chart.defaults.color = '#132A3F';
// ================= Bar chart =================
const barChartDataset = {
    'family_dga 1': 0,
    'family_dga 2': 0,
    'family_dga 3': 0,
    'family_dga 4': 0,
    'family_dga 5': 0,
};

const barChartData = {
    labels: Object.keys(barChartDataset),
    datasets: [
        {
            label: 'DGA Family Probability Scores',
            data: Object.values(barChartDataset),
            backgroundColor: '#132A3F'
        }
    ]
}
const barChartPlugins = {
    legend: {
        labels: {
            font: {
                weight: 'bold'
            }   
        }
    },
}

const barChartScales = {
    y: {
        beginAtZero: true,
        min: 0, // Set the minimum value for the y-axis
        ticks: {
            autoSkip: false, // Disable automatic tick skipping
            minRotation: 0, // Set the minimum label rotation angle
        },
    },
}

const barChartOptions = {
    indexAxis: 'y', //horizontal bar chart
    maintainAspectRatio: false  ,
    responsive: true,
    scaleFontColor: "#black",
    plugins: barChartPlugins,
    scales: barChartScales,
}

const ctx = document.getElementById('dga-bar-chart').getContext('2d');
new Chart(ctx, {
    type: 'bar',
    data: barChartData,
    options: barChartOptions
});

// ================= Pie chart =================
const pieChartData = {
    labels: ['Not DGA', 'DGA'],
    datasets: [
        {
            data: [50,50],
            backgroundColor: ['#9DABB8', '#132A3F'], // Specify colors as needed
            borderWidth:0,
        },
    ],
};
const chartOptions = {
    plugins: {
        legend: {
            labels: {
                font: {
                    weight: 'bold'
                }       
            }
        },
    },
    maintainAspectRatio: false,
    responsive: true,
};
const ctx2 = document.getElementById('dga-pie-chart').getContext('2d');
new Chart(ctx2, {
    type: 'doughnut',
    data: pieChartData,
    options: chartOptions,
});
