/*
  File: dga_clf.js
  Author: Filip Bucko
  Date: 28.9.2023
  Description: Script serves for dynamic chart updating.
*/

function extractDomain(userInputUrl) {
    function extractDomainFromUrl(url) {
        // Remove protocol (http:// or https://) and www if present
        var strippedUrl = url.replace(/^(https?:\/\/)?(www\.)?/, '');
        // Extract the domain (up to the first slash or end of string)
        var domain = strippedUrl.split('/')[0];
        // Remove any trailing slashes or path
        domain = domain.replace(/\/+$/, '');
        return domain;
    }
    // Trim leading/trailing spaces and extract the domain
    var cleanedInputUrl = userInputUrl.trim();
    var domain = extractDomainFromUrl(cleanedInputUrl);

    return domain;
}


// Function to plot the pie chart
function plotPieChart(binary_data) {
    // Sample data in an array
    const canvasElement = document.getElementById('dga-pie-chart');
    const chartInstance = Chart.getChart(canvasElement);
    if (chartInstance) {
        chartInstance.data.datasets[0].data = binary_data;
        chartInstance.update();
    } else {
        console.log('The chart does not exist in the canvas element.');
        return;
    }
}

function plotBarChart(newData) {
    const canvasElement = document.getElementById('dga-bar-chart');
    const chartInstance = Chart.getChart(canvasElement);

    if (chartInstance) {
        // [[labels,data]]
        const newLabels = newData.map(item => item[1]);
        const newDataValues = newData.map(item => item[0]);

        chartInstance.data.labels = newLabels;
        chartInstance.data.datasets[0].data = newDataValues;
        // Update the chart to apply the changes
        chartInstance.update();
    } else {
        console.log('The chart does not exist in the canvas element.');
        return;
    }
}

function setBarChartDefaultsData() {
    const canvasElement = document.getElementById('dga-bar-chart');
    const chartInstance = Chart.getChart(canvasElement)
    if (chartInstance) {
        const defaultBarChartData = {
            'family_dga 1': 0,
            'family_dga 2': 0,
            'family_dga 3': 0,
            'family_dga 4': 0,
            'family_dga 5': 0,
        };
        chartInstance.data.labels = Object.keys(defaultBarChartData);
        chartInstance.data.datasets[0].data = Object.values(defaultBarChartData);
        // Update the chart to apply the changes
        chartInstance.update();
    } else {
        console.log('The chart does not exist in the canvas element.');
        return;
    }
}

$(document).ready(function() {
    var inputField = $("#dga-check-input");
    var submitButton = $("#dga-check-button");
    submitButton.click(function() {
        // Get the user input from the input field
        var userInput = inputField.val();
        if (userInput === "") {
            // Input is empty, prevent form submission and display an error message
            event.preventDefault();
            alert("Please enter a domain.");
        }
        else{
            var domain = extractDomain(userInput)
            // Make an AJAX POST request
            $.ajax({
                type: "POST",
                url: "/dga-check/", // Replace with your API endpoint
                data: JSON.stringify({ text: domain }), // Convert data to JSON
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                success: function(response) {
                    // 1. Plot the binary data
                    var binaryData = response.binary_clf;
                    plotPieChart(binaryData); // Plot the pie chart with the received data
                    // 2. Check if the multiclass data are different than null
                    var multiclassData = response.multiclass_clf;
                    if (multiclassData !== null) {
                        // 3. If they received value is different than null plot the multiclass data
                        plotBarChart(multiclassData);
                    }else{
                        setBarChartDefaultsData();
                    }
                },

                error: function(error) {
                    // Handle errors
                    console.log("Error: " + error.statusText);
                }
            });
            }
        
    });



});
